@@ -1,2 +1,2 @@
-from pywykop3.api import WykopAPI
+from pywykop3.api import ApiException, Comment, Entry, User, WykopAPI
 from pywykop3.connector import Methods, WykopConnector, WykopResponse
