@@ -10,12 +10,57 @@ Comment = NewType("Comment", Dict)
 
 
 class ApiException(Exception):
-    def __init__(self, code, msg) -> None:
+    """
+    This exception is raised by :class:`WykopAPI` when code of request is other than 2xx.
+    Exception has 2 additional attributes:
+
+        - stacode - response code of request
+        - api_msg - message
+    """
+
+    def __init__(self, code: int, api_msg: str) -> None:
+        """
+        Api Exception
+
+        Args:
+            code (int): code of request
+            api_msg (str): message
+        """
         self.code = code
-        super().__init__(f"CODE {self.code}: {msg}")
+        self.api_msg = api_msg
+        super().__init__(f"CODE {self.code}: {api_msg}")
 
 
 class WykopAPI:
+    """
+    Main interface to communicate with Wykop
+    You need to provide
+
+        - connector
+
+        OR
+
+        - key
+        - secret
+
+        OR
+
+        - refresh token
+
+    If you pass key and secret, Wykop will provide information as
+    for non-logged in users.
+    If you refresh_token, Wykop will provide information as
+    for logged in users.
+
+    Args:
+        connector (WykopConnector | None, optional): Connector object. Can be safely ignored.
+            Defaults to None.
+        key (str | None, optional): Key. Defaults to None.
+        secret (str | None, optional): Secret. Defaults to None.
+        refresh_token (str | None, optional): Refresh token. To obtain it,
+            see :meth:`connect()` method. Defaults to None.
+    """
+
     def __init__(
         self,
         connector: WykopConnector | None = None,
@@ -23,7 +68,6 @@ class WykopAPI:
         secret: str | None = None,
         refresh_token: str | None = None,
     ) -> None:
-
         self.connector = connector or WykopConnector(key, secret, refresh_token)
 
     def connect(self) -> str:
@@ -311,17 +355,17 @@ class WykopAPI:
 
         Args:
             sort (str, optional): Rodzaj sortowania.
-            Available values : newest, active, hot. Defaults to "hot".
+                Available values : newest, active, hot. Defaults to "hot".
             last_update (int, optional): Pokaż wyniki z ostatnich godzin
-            [1, 2, 3, 6, 12, 24]. Filtr dostępny tylko wraz z filtrem gorące.
-            Defaults to 12.
+                [1, 2, 3, 6, 12, 24]. Filtr dostępny tylko wraz z filtrem gorące.
+                Defaults to 12.
             page_count (int, optional): Liczba stron do pobrania.
-            Podaj -1, żeby pobrać wszystko. Defaults to 1.
+                Podaj -1, żeby pobrać wszystko. Defaults to 1.
             page (int | str | None, optional): Numer strony do pobrania.
-            Defaults to None.
-            category (str | None, optional): Kategoria. Defaults to None.
-            bucket (str | None, optional): Hash kategorii użytkownika.
-            Defaults to None.
+                Defaults to None.
+            category (str | None, optional): Kategoria.
+                Defaults to None.
+            bucket (str | None, optional): Hash kategorii użytkownika. Defaults to None.
 
         Returns:
             List: Wpisy z mikrobloga.
@@ -346,7 +390,7 @@ class WykopAPI:
         )
         return res.data  # type: ignore
 
-    def post_entries(
+    def post_entry(
         self,
         content: str,
         photo: str | None = None,
@@ -360,13 +404,13 @@ class WykopAPI:
         Args:
             content (str): Treść własna użytkownika.
             photo (str | None, optional): Załącznik użytkownika.
-            W celu dodania należy podać "key" pliku z media/photo.
-            Akceptowane są tylko pliki przesłane jako typ comments.
-            Defaults to None.
+                W celu dodania należy podać "key" pliku z media/photo.
+                Akceptowane są tylko pliki przesłane jako typ comments.
+                Defaults to None.
             embed (str | None, optional): Unikatowy identyfikator embed.
-            Defaults to None.
+                Defaults to None.
             survey (str | None, optional): Ankieta użytkownika.
-            W celu dodania należy podać Indentyfikator. Defaults to None.
+                W celu dodania należy podać Indentyfikator. Defaults to None.
             adult (bool, optional): Wpis tylko dla dorosłych. Defaults to False.
 
         Returns:
@@ -390,7 +434,7 @@ class WykopAPI:
         )
         return res.data  # type: ignore
 
-    def get_entry_by_id(self, entry_id: int) -> Dict:
+    def get_entry_by_id(self, entry_id: int) -> Entry:
         """
         Zwraca wpisz z mikrobloga.
 
@@ -410,7 +454,7 @@ class WykopAPI:
         )
         return res.data  # type: ignore
 
-    def put_entries(
+    def put_entry(
         self,
         entry_id: int,
         content: str,
@@ -427,13 +471,13 @@ class WykopAPI:
             entry_id (int): Identyfikator wpisu
             content (str): Treść własna użytkownika.
             photo (str | None, optional): Załącznik użytkownika.
-            W celu dodania należy podać "key" pliku z media/photo.
-            Akceptowane są tylko pliki przesłane jako typ comments.
-            Defaults to None.
+                W celu dodania należy podać "key" pliku z media/photo.
+                Akceptowane są tylko pliki przesłane jako typ comments.
+                Defaults to None.
             embed (str | None, optional): Unikatowy identyfikator embed.
-            Defaults to None.
+                Defaults to None.
             survey (str | None, optional): Ankieta użytkownika.
-            W celu dodania należy podać Indentyfikator. Defaults to None.
+                W celu dodania należy podać Indentyfikator. Defaults to None.
             adult (bool, optional): Wpis tylko dla dorosłych. Defaults to False.
 
         Returns:
@@ -566,9 +610,9 @@ class WykopAPI:
         Args:
             entry_id (int): Identyfikator wpisu
             page (int, optional): Numer strony do pobrania.
-            Defaults to 1.
+                Defaults to 1.
             page_count (int, optional): Liczba stron do pobrania.
-            Podaj -1, żeby pobrać wszystko. Defaults to 1.
+                Podaj -1, żeby pobrać wszystko. Defaults to 1.
 
         Returns:
             List[Comment]: _description_
@@ -595,16 +639,16 @@ class WykopAPI:
         Args:
             entry_id (int): Identyfikator wpisu
             content (str): Treść własna użytkownika. Treść może być pusta w
-            przypadku dodania innych multimediów.
-            W przypadku samej treści musi zawierać min. 5 znaków.
+                przypadku dodania innych multimediów.
+                W przypadku samej treści musi zawierać min. 5 znaków.
             embed (str | None, optional): Unikatowy identyfikator pliku.
-            Defaults to None.
+                Defaults to None.
             photo (str | None, optional): Załącznik użytkownika. W celu
-            dodania należy podać "key" pliku z media/photo.
-            Akceptowane są tylko pliki przesłane jako typ comments.
-            Defaults to None.
+                dodania należy podać "key" pliku z media/photo.
+                Akceptowane są tylko pliki przesłane jako typ comments.
+                Defaults to None.
             adult (bool, optional): Komentarz tylko dla dorosłych.
-            Defaults to False.
+                Defaults to False.
 
         Returns:
             Comment: Dodany komentarz
@@ -665,16 +709,16 @@ class WykopAPI:
             entry_id (int): Identyfikator wpisu
             comment_id (int): Identyfikator komentarza
             content (str): Treść własna użytkownika. Treść może być pusta w
-            przypadku dodania innych multimediów.
-            W przypadku samej treści musi zawierać min. 5 znaków.
+                przypadku dodania innych multimediów.
+                W przypadku samej treści musi zawierać min. 5 znaków.
             embed (str | None, optional): Unikatowy identyfikator pliku.
-            Defaults to None.
+                Defaults to None.
             photo (str | None, optional): Załącznik użytkownika. W celu
-            dodania należy podać "key" pliku z media/photo.
-            Akceptowane są tylko pliki przesłane jako typ comments.
-            Defaults to None.
+                dodania należy podać "key" pliku z media/photo.
+                Akceptowane są tylko pliki przesłane jako typ comments.
+                Defaults to None.
             adult (bool, optional): Komentarz tylko dla dorosłych.
-            Defaults to False.
+                Defaults to False.
 
         Returns:
             Comment: Zmodyfikowany komentarz
